@@ -17,8 +17,8 @@ import (
 func (c *configCommand) newEditCommand() *cobra.Command {
 	cmd := &cobra.Command{
 		Use:   "edit",
-		Short: "Edit the audit-log config spec interactively.",
-		Long:  "Edit the audit-log config spec object interactively, using the $EDITOR specified in your environment (for example, vim).",
+		Short: "Edit the audit-log configuration specification interactively.",
+		Long:  "Edit the audit-log configuration specification object interactively using the $EDITOR specified in your environment (for example, vim).",
 		Args:  cobra.NoArgs,
 		RunE:  c.edit,
 	}
