@@ -4,22 +4,27 @@ import (
 	"github.com/spf13/cobra"
 
 	pcmd "github.com/confluentinc/cli/internal/pkg/cmd"
+	v1 "github.com/confluentinc/cli/internal/pkg/config/v1"
 )
 
 type clientConfigCommand struct {
-	*pcmd.HasAPIKeyCLICommand
+	*pcmd.AuthenticatedCLICommand
+	clientId string
 }
 
-func newClientConfigCommand(prerunner pcmd.PreRunner, clientId string) *cobra.Command {
+func newClientConfigCommand(cfg *v1.Config, prerunner pcmd.PreRunner) *cobra.Command {
 	cmd := &cobra.Command{
 		Use:         "client-config",
 		Short:       "Manage Kafka Clients configuration files.",
 		Annotations: map[string]string{pcmd.RunRequirement: pcmd.RequireNonAPIKeyCloudLogin},
 	}
 
-	c := &clientConfigCommand{pcmd.NewHasAPIKeyCLICommand(cmd, prerunner)}
+	c := &clientConfigCommand{
+		AuthenticatedCLICommand: pcmd.NewAuthenticatedCLICommand(cmd, prerunner),
+		clientId:                cfg.Version.ClientID,
+	}
 
-	cmd.AddCommand(c.newCreateCommand(prerunner, clientId))
+	cmd.AddCommand(c.newCreateCommand())
 
 	return cmd
 }
