@@ -8,7 +8,6 @@ import (
 	pcmd "github.com/confluentinc/cli/internal/pkg/cmd"
 	"github.com/confluentinc/cli/internal/pkg/errors"
 	"github.com/confluentinc/cli/internal/pkg/examples"
-	"github.com/confluentinc/cli/internal/pkg/kafkarest"
 	"github.com/confluentinc/cli/internal/pkg/output"
 	"github.com/confluentinc/cli/internal/pkg/properties"
 	"github.com/confluentinc/cli/internal/pkg/resource"
@@ -85,14 +84,6 @@ func (c *mirrorCommand) create(cmd *cobra.Command, args []string) error {
 	}
 
 	kafkaREST, err := c.GetKafkaREST()
-	if kafkaREST == nil {
-		if err != nil {
-			return err
-		}
-		return errors.New(errors.RestProxyNotAvailableMsg)
-	}
-
-	cluster, err := c.Context.GetKafkaClusterForCommand()
 	if err != nil {
 		return err
 	}
@@ -109,8 +100,8 @@ func (c *mirrorCommand) create(cmd *cobra.Command, args []string) error {
 		createMirrorTopicRequestData.MirrorTopicName = &mirrorTopicName
 	}
 
-	if httpResp, err := kafkaREST.CloudClient.CreateKafkaMirrorTopic(cluster.ID, linkName, createMirrorTopicRequestData); err != nil {
-		return kafkarest.NewError(kafkaREST.CloudClient.GetUrl(), err, httpResp)
+	if err := kafkaREST.CloudClient.CreateKafkaMirrorTopic(linkName, createMirrorTopicRequestData); err != nil {
+		return err
 	}
 
 	output.Printf(errors.CreatedResourceMsg, resource.MirrorTopic, mirrorTopicName)
