@@ -8,6 +8,7 @@ import (
 	"strconv"
 	"strings"
 
+	"github.com/antihax/optional"
 	"github.com/spf13/cobra"
 
 	ckafka "github.com/confluentinc/confluent-kafka-go/kafka"
@@ -31,16 +32,19 @@ func (c *command) newProduceCommand() *cobra.Command {
 		Annotations:       map[string]string{pcmd.RunRequirement: pcmd.RequireCloudLogin},
 	}
 
+	cmd.Flags().String("key-schema", "", "The ID or filepath of the message key schema.")
 	cmd.Flags().String("schema", "", "The ID or filepath of the message value schema.")
+	pcmd.AddKeyFormatFlag(cmd)
 	pcmd.AddValueFormatFlag(cmd)
-	cmd.Flags().String("references", "", "The path to the references file.")
+	cmd.Flags().String("key-references", "", "The path to the message key schema references file.")
+	cmd.Flags().String("references", "", "The path to the message value schema references file.")
 	cmd.Flags().Bool("parse-key", false, "Parse key from the message.")
 	cmd.Flags().String("delimiter", ":", "The delimiter separating each key and value.")
 	cmd.Flags().StringSlice("config", nil, `A comma-separated list of configuration overrides ("key=value") for the producer client.`)
 	pcmd.AddProducerConfigFileFlag(cmd)
 	cmd.Flags().String("schema-registry-endpoint", "", "Endpoint for Schema Registry cluster.")
 	cmd.Flags().String("schema-registry-api-key", "", "Schema registry API key.")
-	cmd.Flags().String("schema-registry-api-secret", "", "Schema registry API key secret.")
+	cmd.Flags().String("schema-registry-api-secret", "", "Schema registry API secret.")
 	pcmd.AddApiKeyFlag(cmd, c.AuthenticatedCLICommand)
 	pcmd.AddApiSecretFlag(cmd)
 	pcmd.AddClusterFlag(cmd, c.AuthenticatedCLICommand)
@@ -55,6 +59,7 @@ func (c *command) newProduceCommand() *cobra.Command {
 	cmd.Flags().Int32("schema-id", 0, "The ID of the schema.")
 	cobra.CheckErr(cmd.Flags().MarkHidden("schema-id"))
 
+	cobra.CheckErr(cmd.MarkFlagFilename("key-references", "json"))
 	cobra.CheckErr(cmd.MarkFlagFilename("references", "json"))
 	cobra.CheckErr(cmd.MarkFlagFilename("config-file", "avsc", "json"))
 
@@ -76,7 +81,12 @@ func (c *command) produce(cmd *cobra.Command, args []string) error {
 		return err
 	}
 
-	serializationProvider, metaInfo, err := c.initSchemaAndGetInfo(cmd, topic)
+	keySerializer, keyMetaInfo, err := c.initSchemaAndGetInfo(cmd, topic, "key")
+	if err != nil {
+		return err
+	}
+
+	valueSerializer, valueMetaInfo, err := c.initSchemaAndGetInfo(cmd, topic, "value")
 	if err != nil {
 		return err
 	}
@@ -124,23 +134,23 @@ func (c *command) produce(cmd *cobra.Command, args []string) error {
 
 	deliveryChan := make(chan ckafka.Event)
 	for data := range input {
-		if len(data) == 0 {
+		if data == "" {
 			go scan()
 			continue
 		}
 
-		msg, err := GetProduceMessage(cmd, metaInfo, topic, data, serializationProvider)
+		message, err := GetProduceMessage(cmd, keyMetaInfo, valueMetaInfo, topic, data, keySerializer, valueSerializer)
 		if err != nil {
 			return err
 		}
-		if err := producer.Produce(msg, deliveryChan); err != nil {
+		if err := producer.Produce(message, deliveryChan); err != nil {
 			isProduceToCompactedTopicError, err := errors.CatchProduceToCompactedTopicError(err, topic)
 			if isProduceToCompactedTopicError {
 				scanErr = err
 				close(input)
 				break
 			}
-			output.ErrPrintf(errors.FailedToProduceErrorMsg, msg.TopicPartition.Offset, err)
+			output.ErrPrintf(errors.FailedToProduceErrorMsg, message.TopicPartition.Offset, err)
 		}
 
 		e := <-deliveryChan                // read a ckafka event from the channel
@@ -203,125 +213,142 @@ func PrepareInputChannel(scanErr *error) (chan string, func()) {
 	}
 }
 
-func GetProduceMessage(cmd *cobra.Command, metaInfo []byte, topicName, data string, serializationProvider serdes.SerializationProvider) (*ckafka.Message, error) {
+func GetProduceMessage(cmd *cobra.Command, keyMetaInfo, valueMetaInfo []byte, topic, data string, keySerializer, valueSerializer serdes.SerializationProvider) (*ckafka.Message, error) {
 	parseKey, err := cmd.Flags().GetBool("parse-key")
 	if err != nil {
 		return nil, err
 	}
+
 	delimiter, err := cmd.Flags().GetString("delimiter")
 	if err != nil {
 		return nil, err
 	}
-	key, value, err := getMsgKeyAndValue(metaInfo, data, delimiter, parseKey, serializationProvider)
+
+	key, value, err := serializeMessage(keyMetaInfo, valueMetaInfo, data, delimiter, parseKey, keySerializer, valueSerializer)
 	if err != nil {
 		return nil, err
 	}
 
-	return &ckafka.Message{
-		TopicPartition: ckafka.TopicPartition{Topic: &topicName, Partition: ckafka.PartitionAny},
-		Key:            []byte(key),
-		Value:          []byte(value),
-	}, nil
+	message := &ckafka.Message{
+		TopicPartition: ckafka.TopicPartition{
+			Topic:     &topic,
+			Partition: ckafka.PartitionAny,
+		},
+		Key:   key,
+		Value: value,
+	}
+
+	return message, nil
 }
 
-func getMsgKeyAndValue(metaInfo []byte, data, delimiter string, parseKey bool, serializationProvider serdes.SerializationProvider) (string, string, error) {
-	var key, valueString string
+func serializeMessage(keyMetaInfo, valueMetaInfo []byte, data, delimiter string, parseKey bool, keySerializer, valueSerializer serdes.SerializationProvider) ([]byte, []byte, error) {
+	var serializedKey, val string
 	if parseKey {
-		record := strings.SplitN(data, delimiter, 2)
-		valueString = strings.TrimSpace(record[len(record)-1])
-
-		if len(record) == 2 {
-			key = strings.TrimSpace(record[0])
-		} else {
-			return "", "", errors.New(errors.MissingKeyErrorMsg)
+		x := strings.SplitN(data, delimiter, 2)
+		if len(x) != 2 {
+			return nil, nil, errors.New(errors.MissingKeyErrorMsg)
 		}
+
+		out, err := serdes.Serialize(keySerializer, strings.TrimSpace(x[0]))
+		if err != nil {
+			return nil, nil, err
+		}
+		serializedKey = string(out)
+
+		val = strings.TrimSpace(x[1])
 	} else {
-		valueString = strings.TrimSpace(data)
+		val = strings.TrimSpace(data)
 	}
-	encodedMessage, err := serdes.Serialize(serializationProvider, valueString)
+
+	serializedValue, err := serdes.Serialize(valueSerializer, val)
 	if err != nil {
-		return "", "", err
+		return nil, nil, err
 	}
-	value := string(append(metaInfo, encodedMessage...))
-	return key, value, nil
+
+	return append(keyMetaInfo, serializedKey...), append(valueMetaInfo, serializedValue...), nil
 }
 
-func (c *command) initSchemaAndGetInfo(cmd *cobra.Command, topic string) (serdes.SerializationProvider, []byte, error) {
-	dir, err := sr.CreateTempDir()
+func (c *command) initSchemaAndGetInfo(cmd *cobra.Command, topic, mode string) (serdes.SerializationProvider, []byte, error) {
+	schemaDir, err := sr.CreateTempDir()
 	if err != nil {
 		return nil, nil, err
 	}
 	defer func() {
-		_ = os.RemoveAll(dir)
+		_ = os.RemoveAll(schemaDir)
 	}()
 
 	subject := topicNameStrategy(topic)
 
 	// Deprecated
-	schemaId, err := cmd.Flags().GetInt32("schema-id")
+	var schemaId optional.Int32
+	if mode == "value" && cmd.Flags().Changed("schema-id") {
+		id, err := cmd.Flags().GetInt32("schema-id")
+		if err != nil {
+			return nil, nil, err
+		}
+		schemaId = optional.NewInt32(id)
+	}
+
+	schemaFlagName := "schema"
+	if mode == "key" {
+		schemaFlagName = "key-schema"
+	}
+	schema, err := cmd.Flags().GetString(schemaFlagName)
 	if err != nil {
 		return nil, nil, err
 	}
-
-	schemaPath, err := cmd.Flags().GetString("schema")
-	if err != nil {
-		return nil, nil, err
+	if id, err := strconv.ParseInt(schema, 10, 32); err == nil {
+		schemaId = optional.NewInt32(int32(id))
 	}
 
-	isSchemaId := cmd.Flags().Changed("schema-id")
-	if id, err := strconv.ParseInt(schemaPath, 10, 32); err == nil {
-		schemaId = int32(id)
-		isSchemaId = true
-	}
-
-	var valueFormat string
+	var format string
 	referencePathMap := map[string]string{}
 	metaInfo := []byte{}
 
-	if isSchemaId {
+	if schemaId.IsSet() {
 		srClient, err := c.GetSchemaRegistryClient()
 		if err != nil {
 			return nil, nil, err
 		}
 
-		schemaString, err := sr.RequestSchemaWithId(schemaId, subject, srClient)
+		schemaString, err := sr.RequestSchemaWithId(schemaId.Value(), subject, srClient)
 		if err != nil {
 			return nil, nil, err
 		}
 
-		valueFormat, err = serdes.FormatTranslation(schemaString.SchemaType)
+		format, err = serdes.FormatTranslation(schemaString.SchemaType)
 		if err != nil {
 			return nil, nil, err
 		}
 
-		schemaPath, referencePathMap, err = sr.SetSchemaPathRef(schemaString, dir, subject, schemaId, srClient)
+		schema, referencePathMap, err = sr.SetSchemaPathRef(schemaString, schemaDir, subject, schemaId.Value(), srClient)
 		if err != nil {
 			return nil, nil, err
 		}
 
-		metaInfo = sr.GetMetaInfoFromSchemaId(schemaId)
+		metaInfo = sr.GetMetaInfoFromSchemaId(schemaId.Value())
 	} else {
-		valueFormat, err = cmd.Flags().GetString("value-format")
+		format, err = cmd.Flags().GetString(fmt.Sprintf("%s-format", mode))
 		if err != nil {
 			return nil, nil, err
 		}
 	}
 
-	serializationProvider, err := serdes.GetSerializationProvider(valueFormat)
+	serializationProvider, err := serdes.GetSerializationProvider(format)
 	if err != nil {
 		return nil, nil, err
 	}
 
-	if schemaPath != "" && !isSchemaId {
+	if schema != "" && !schemaId.IsSet() {
 		// read schema info from local file and register schema
 		schemaCfg := &sr.RegisterSchemaConfigs{
-			SchemaDir:   dir,
-			SchemaPath:  schemaPath,
-			Subject:     subject,
-			ValueFormat: valueFormat,
-			SchemaType:  serializationProvider.GetSchemaName(),
+			SchemaDir:  schemaDir,
+			SchemaPath: schema,
+			Subject:    subject,
+			Format:     format,
+			SchemaType: serializationProvider.GetSchemaName(),
 		}
-		refs, err := sr.ReadSchemaReferences(cmd)
+		refs, err := sr.ReadSchemaReferences(cmd, mode == "key")
 		if err != nil {
 			return nil, nil, err
 		}
@@ -332,7 +359,7 @@ func (c *command) initSchemaAndGetInfo(cmd *cobra.Command, topic string) (serdes
 		}
 	}
 
-	if err := serializationProvider.LoadSchema(schemaPath, referencePathMap); err != nil {
+	if err := serializationProvider.LoadSchema(schema, referencePathMap); err != nil {
 		return nil, nil, errors.NewWrapErrorWithSuggestions(err, "failed to load schema", "Specify a schema by passing a schema ID or the path to a schema file to the `--schema` flag.")
 	}
 
