@@ -95,7 +95,7 @@ func fromArgs(conf *ACLConfiguration) func(*pflag.Flag) {
 
 func setConfigPrincipal(conf *ACLConfiguration, isServiceAccount bool, v string) {
 	if conf.Entry.Principal != "" {
-		conf.errors = multierror.Append(conf.errors, fmt.Errorf(errors.ExactlyOneSetErrorMsg, "service-account, principal"))
+		conf.errors = multierror.Append(conf.errors, fmt.Errorf(errors.ExactlyOneSetErrorMsg, "`--service-account`, `--principal`"))
 		return
 	}
 
