@@ -14,27 +14,29 @@ import (
 )
 
 type humanOut struct {
-	Id                  string    `human:"ID"`
-	Name                string    `human:"Name"`
-	Description         string    `human:"Description"`
-	KsqlCluster         string    `human:"KSQL Cluster"`
-	SecretNames         string    `human:"Secret Names,omitempty"`
-	ActivationPrivilege bool      `human:"Activation Privilege"`
-	State               string    `human:"State"`
-	CreatedAt           time.Time `human:"Created At"`
-	UpdatedAt           time.Time `human:"Updated At"`
+	Id                    string    `human:"ID"`
+	Name                  string    `human:"Name"`
+	Description           string    `human:"Description"`
+	KsqlCluster           string    `human:"KSQL Cluster,omitempty"`
+	SchemaRegistryCluster string    `human:"Schema Registry Cluster,omitempty"`
+	SecretNames           string    `human:"Secret Names,omitempty"`
+	ActivationPrivilege   bool      `human:"Activation Privilege"`
+	State                 string    `human:"State"`
+	CreatedAt             time.Time `human:"Created At"`
+	UpdatedAt             time.Time `human:"Updated At"`
 }
 
 type serializedOut struct {
-	Id                  string    `serialized:"id"`
-	Name                string    `serialized:"name"`
-	Description         string    `serialized:"description"`
-	KsqlCluster         string    `serialized:"ksql_cluster"`
-	SecretNames         []string  `serialized:"secret_names,omitempty"`
-	ActivationPrivilege bool      `serialized:"activation_privilege"`
-	State               string    `serialized:"state"`
-	CreatedAt           time.Time `serialized:"created_at"`
-	UpdatedAt           time.Time `serialized:"updated_at"`
+	Id                    string    `serialized:"id"`
+	Name                  string    `serialized:"name"`
+	Description           string    `serialized:"description"`
+	KsqlCluster           string    `serialized:"ksql_cluster"`
+	SchemaRegistryCluster string    `serialized:"schema_registry_cluster"`
+	SecretNames           []string  `serialized:"secret_names,omitempty"`
+	ActivationPrivilege   bool      `serialized:"activation_privilege"`
+	State                 string    `serialized:"state"`
+	CreatedAt             time.Time `serialized:"created_at"`
+	UpdatedAt             time.Time `serialized:"updated_at"`
 }
 
 var (
@@ -73,27 +75,29 @@ func printTable(cmd *cobra.Command, pipeline streamdesignerv1.SdV1Pipeline) erro
 
 	if output.GetFormat(cmd) == output.Human {
 		table.Add(&humanOut{
-			Id:                  pipeline.GetId(),
-			Name:                pipeline.Spec.GetDisplayName(),
-			Description:         pipeline.Spec.GetDescription(),
-			KsqlCluster:         pipeline.Spec.KsqlCluster.GetId(),
-			SecretNames:         strings.Join(secrets, ", "),
-			ActivationPrivilege: pipeline.Spec.GetActivationPrivilege(),
-			State:               pipeline.Status.GetState(),
-			CreatedAt:           pipeline.Metadata.GetCreatedAt(),
-			UpdatedAt:           pipeline.Metadata.GetUpdatedAt(),
+			Id:                    pipeline.GetId(),
+			Name:                  pipeline.Spec.GetDisplayName(),
+			Description:           pipeline.Spec.GetDescription(),
+			KsqlCluster:           pipeline.Spec.KsqlCluster.GetId(),
+			SchemaRegistryCluster: pipeline.Spec.StreamGovernanceCluster.GetId(),
+			SecretNames:           strings.Join(secrets, ", "),
+			ActivationPrivilege:   pipeline.Spec.GetActivationPrivilege(),
+			State:                 pipeline.Status.GetState(),
+			CreatedAt:             pipeline.Metadata.GetCreatedAt(),
+			UpdatedAt:             pipeline.Metadata.GetUpdatedAt(),
 		})
 	} else {
 		table.Add(&serializedOut{
-			Id:                  pipeline.GetId(),
-			Name:                pipeline.Spec.GetDisplayName(),
-			Description:         pipeline.Spec.GetDescription(),
-			KsqlCluster:         pipeline.Spec.KsqlCluster.GetId(),
-			SecretNames:         secrets,
-			ActivationPrivilege: pipeline.Spec.GetActivationPrivilege(),
-			State:               pipeline.Status.GetState(),
-			CreatedAt:           pipeline.Metadata.GetCreatedAt(),
-			UpdatedAt:           pipeline.Metadata.GetUpdatedAt(),
+			Id:                    pipeline.GetId(),
+			Name:                  pipeline.Spec.GetDisplayName(),
+			Description:           pipeline.Spec.GetDescription(),
+			KsqlCluster:           pipeline.Spec.KsqlCluster.GetId(),
+			SchemaRegistryCluster: pipeline.Spec.StreamGovernanceCluster.GetId(),
+			SecretNames:           secrets,
+			ActivationPrivilege:   pipeline.Spec.GetActivationPrivilege(),
+			State:                 pipeline.Status.GetState(),
+			CreatedAt:             pipeline.Metadata.GetCreatedAt(),
+			UpdatedAt:             pipeline.Metadata.GetUpdatedAt(),
 		})
 	}
 
