@@ -48,7 +48,6 @@ func (c *command) clusterDelete(cmd *cobra.Command, _ []string) error {
 	if err != nil {
 		return err
 	}
-
 	if len(clusters) == 0 {
 		return errors.NewSRNotEnabledError()
 	}
@@ -58,7 +57,7 @@ func (c *command) clusterDelete(cmd *cobra.Command, _ []string) error {
 		return err
 	}
 
-	if err = c.V2Client.DeleteSchemaRegistryCluster(clusters[0].GetId(), environmentId); err != nil {
+	if err := c.V2Client.DeleteSchemaRegistryCluster(clusters[0].GetId(), environmentId); err != nil {
 		return err
 	}
 
