@@ -29,7 +29,7 @@ func AddApiKeyFlag(cmd *cobra.Command, c *AuthenticatedCLICommand) {
 }
 
 func AddApiSecretFlag(cmd *cobra.Command) {
-	cmd.Flags().String("api-secret", "", "API key secret.")
+	cmd.Flags().String("api-secret", "", "API secret.")
 }
 
 func AutocompleteApiKeys(client *ccloudv2.Client) []string {
@@ -396,6 +396,17 @@ func AddTypeFlag(cmd *cobra.Command) {
 	RegisterFlagCompletionFunc(cmd, "type", func(_ *cobra.Command, _ []string) []string { return kafka.Types })
 }
 
+func AddKeyFormatFlag(cmd *cobra.Command) {
+	arr := []string{"string", "avro", "jsonschema", "protobuf"}
+	str := utils.ArrayToCommaDelimitedString(arr, "or")
+
+	cmd.Flags().String("key-format", "string", fmt.Sprintf("Format of message key as %s. Note that schema references are not supported for Avro.", str))
+
+	RegisterFlagCompletionFunc(cmd, "key-format", func(_ *cobra.Command, _ []string) []string {
+		return arr
+	})
+}
+
 func AddValueFormatFlag(cmd *cobra.Command) {
 	arr := []string{"string", "avro", "jsonschema", "protobuf"}
 	str := utils.ArrayToCommaDelimitedString(arr, "or")
@@ -421,16 +432,11 @@ func AddLinkFlag(cmd *cobra.Command, command *AuthenticatedCLICommand) {
 
 func AutocompleteLinks(command *AuthenticatedCLICommand) []string {
 	kafkaREST, err := command.GetKafkaREST()
-	if err != nil || kafkaREST == nil {
-		return nil
-	}
-
-	kafkaClusterConfig, err := command.Context.GetKafkaClusterForCommand()
 	if err != nil {
 		return nil
 	}
 
-	links, _, err := kafkaREST.CloudClient.ListKafkaLinks(kafkaClusterConfig.ID)
+	links, err := kafkaREST.CloudClient.ListKafkaLinks()
 	if err != nil {
 		return nil
 	}
