@@ -245,17 +245,11 @@ func (r *PreRun) ParseFlagsIntoContext(command *CLICommand) func(*cobra.Command,
 
 func (r *PreRun) setAuthenticatedContext(cliCommand *AuthenticatedCLICommand) error {
 	ctx := cliCommand.Config.Context()
-	if ctx == nil {
+	if ctx == nil || !ctx.HasLogin() {
 		return new(errors.NotLoggedInError)
 	}
 	cliCommand.Context = ctx
 
-	state, err := ctx.AuthenticatedState()
-	if err != nil {
-		return err
-	}
-	cliCommand.State = state
-
 	return nil
 }
 
@@ -356,25 +350,24 @@ func (r *PreRun) setCCloudClient(c *AuthenticatedCLICommand) error {
 		if cluster.Status.Phase == ccloudv2.StatusProvisioning {
 			return nil, errors.Errorf(errors.KafkaRestProvisioningErrorMsg, lkc)
 		}
-		if restEndpoint != "" {
-			state, err := ctx.AuthenticatedState()
-			if err != nil {
-				return nil, err
-			}
-
-			dataplaneToken, err := pauth.GetDataplaneToken(state, ctx.Platform.Server)
-			if err != nil {
-				return nil, err
-			}
-			kafkaRest := &KafkaREST{
-				Context:     context.WithValue(context.Background(), kafkarestv3.ContextAccessToken, dataplaneToken),
-				CloudClient: ccloudv2.NewKafkaRestClient(restEndpoint, r.Version.UserAgent, unsafeTrace, dataplaneToken),
-				Client:      CreateKafkaRESTClient(restEndpoint, unsafeTrace),
-			}
-
-			return kafkaRest, nil
+		if restEndpoint == "" {
+			return nil, errors.New("Kafka REST is not enabled: the operation is only supported with Kafka REST proxy.")
 		}
-		return nil, nil
+
+		state, err := ctx.AuthenticatedState()
+		if err != nil {
+			return nil, err
+		}
+		dataplaneToken, err := pauth.GetDataplaneToken(state, ctx.Platform.Server)
+		if err != nil {
+			return nil, err
+		}
+		kafkaRest := &KafkaREST{
+			Context:     context.WithValue(context.Background(), kafkarestv3.ContextAccessToken, dataplaneToken),
+			CloudClient: ccloudv2.NewKafkaRestClient(restEndpoint, lkc, r.Version.UserAgent, dataplaneToken, unsafeTrace),
+			Client:      CreateKafkaRESTClient(restEndpoint, unsafeTrace),
+		}
+		return kafkaRest, nil
 	})
 	c.KafkaRESTProvider = &provider
 	return nil
@@ -494,7 +487,6 @@ func (r *PreRun) setAuthenticatedWithMDSContext(cliCommand *AuthenticatedCLIComm
 		return new(errors.NotLoggedInError)
 	}
 	cliCommand.Context = ctx
-	cliCommand.State = ctx.State
 
 	unsafeTrace, err := cliCommand.Flags().GetBool("unsafe-trace")
 	if err != nil {
@@ -618,7 +610,7 @@ func (r *PreRun) InitializeOnPremKafkaRest(command *AuthenticatedCLICommand) fun
 			var restContext context.Context
 			if useMdsToken && !restFlags.prompt {
 				log.CliLogger.Debug("found mds token to use as bearer")
-				restContext = context.WithValue(context.Background(), kafkarestv3.ContextAccessToken, command.AuthToken())
+				restContext = context.WithValue(context.Background(), kafkarestv3.ContextAccessToken, command.Context.GetAuthToken())
 			} else { // no mds token, then prompt for basic auth creds
 				if !restFlags.prompt {
 					output.Println(errors.MDSTokenNotFoundMsg)
@@ -675,7 +667,7 @@ func resolveOnPremKafkaRestFlags(cmd *cobra.Command) (*onPremKafkaRestFlagValues
 	return values, nil
 }
 
-func createOnPremKafkaRestClient(ctx *dynamicconfig.DynamicContext, caCertPath string, clientCertPath string, clientKeyPath string, logger *log.Logger) (*http.Client, error) {
+func createOnPremKafkaRestClient(ctx *dynamicconfig.DynamicContext, caCertPath, clientCertPath, clientKeyPath string, logger *log.Logger) (*http.Client, error) {
 	if caCertPath == "" {
 		caCertPath = pauth.GetEnvWithFallback(pauth.ConfluentPlatformCACertPath, pauth.DeprecatedConfluentPlatformCACertPath)
 		logger.Debugf("Found CA cert path: %s", caCertPath)
