@@ -11,13 +11,11 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/hashicorp/go-version"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
 	ccloudv1 "github.com/confluentinc/ccloud-sdk-go-v1-public"
 
-	"github.com/confluentinc/cli/internal/pkg/config"
 	"github.com/confluentinc/cli/internal/pkg/utils"
 	pversion "github.com/confluentinc/cli/internal/pkg/version"
 	testserver "github.com/confluentinc/cli/test/test-server"
@@ -161,10 +159,7 @@ func SetupTestInputs(isCloud bool) *TestInputs {
 		context = "cloud"
 	}
 	testInputs.statefulConfig = &Config{
-		BaseConfig: &config.BaseConfig{
-			Filename: fmt.Sprintf("test_json/stateful_%s.json", context),
-			Ver:      config.Version{Version: ver},
-		},
+		Filename:  fmt.Sprintf("test_json/stateful_%s.json", context),
 		Platforms: map[string]*Platform{platform.Name: platform},
 		Credentials: map[string]*Credential{
 			apiCredential.Name:   apiCredential,
@@ -177,10 +172,7 @@ func SetupTestInputs(isCloud bool) *TestInputs {
 		SavedCredentials: savedCredentials,
 	}
 	testInputs.statelessConfig = &Config{
-		BaseConfig: &config.BaseConfig{
-			Filename: fmt.Sprintf("test_json/stateless_%s.json", context),
-			Ver:      config.Version{Version: ver},
-		},
+		Filename:  fmt.Sprintf("test_json/stateless_%s.json", context),
 		Platforms: map[string]*Platform{platform.Name: platform},
 		Credentials: map[string]*Credential{
 			apiCredential.Name:   apiCredential,
@@ -193,10 +185,7 @@ func SetupTestInputs(isCloud bool) *TestInputs {
 		SavedCredentials: savedCredentials,
 	}
 	testInputs.twoEnvStatefulConfig = &Config{
-		BaseConfig: &config.BaseConfig{
-			Filename: fmt.Sprintf("test_json/stateful_%s.json", context),
-			Ver:      config.Version{Version: ver},
-		},
+		Filename:  fmt.Sprintf("test_json/stateful_%s.json", context),
 		Platforms: map[string]*Platform{platform.Name: platform},
 		Credentials: map[string]*Credential{
 			apiCredential.Name:   apiCredential,
@@ -252,10 +241,7 @@ func TestConfig_Load(t *testing.T) {
 		{
 			name: "should load disable update checks and disable updates",
 			want: &Config{
-				BaseConfig: &config.BaseConfig{
-					Filename: "test_json/load_disable_update.json",
-					Ver:      config.Version{Version: ver},
-				},
+				Filename:           "test_json/load_disable_update.json",
 				DisableUpdates:     true,
 				DisableUpdateCheck: true,
 				Platforms:          map[string]*Platform{},
@@ -279,7 +265,6 @@ func TestConfig_Load(t *testing.T) {
 			}
 
 			// Get around automatically assigned anonymous id and IsTest check
-			test.want.AnonymousId = cfg.AnonymousId
 			test.want.IsTest = cfg.IsTest
 			test.want.Version = cfg.Version
 			test.want.Credentials = cfg.Credentials
@@ -414,7 +399,7 @@ func TestConfig_SaveWithEnvironmentOverwrite(t *testing.T) {
 	}
 }
 
-func replacePlaceholdersInWant(t *testing.T, got []byte, want []byte) string {
+func replacePlaceholdersInWant(t *testing.T, got, want []byte) string {
 	data := &Config{}
 	err := json.Unmarshal(got, data)
 	require.NoError(t, err)
@@ -608,7 +593,6 @@ func TestConfig_AddContext(t *testing.T) {
 	}
 
 	test := testStruct{
-		name:               "",
 		config:             noContextConf,
 		contextName:        context.Name,
 		platformName:       context.PlatformName,
@@ -618,8 +602,6 @@ func TestConfig_AddContext(t *testing.T) {
 		kafka:              context.KafkaClusterContext.ActiveKafkaCluster,
 		state:              context.State,
 		filename:           filename,
-		want:               nil,
-		wantErr:            false,
 	}
 
 	addValidContextTest := test
@@ -642,9 +624,6 @@ func TestConfig_AddContext(t *testing.T) {
 			if (err != nil) != test.wantErr {
 				t.Errorf("AddContext() error = %v, wantErr %v", err, test.wantErr)
 			}
-			if test.want != nil {
-				test.want.AnonymousId = test.config.AnonymousId
-			}
 			if !test.wantErr && !reflect.DeepEqual(test.want, test.config) {
 				t.Errorf("AddContext() got = %v, want %v", test.config, test.want)
 			}
@@ -655,7 +634,6 @@ func TestConfig_AddContext(t *testing.T) {
 
 func TestConfig_CreateContext(t *testing.T) {
 	cfg := &Config{
-		BaseConfig:    &config.BaseConfig{Ver: config.Version{Version: version.Must(version.NewVersion("1.0.0"))}},
 		ContextStates: make(map[string]*ContextState),
 		Contexts:      make(map[string]*Context),
 		Credentials:   make(map[string]*Credential),
