@@ -1,10 +1,12 @@
 package v1
 
-// Credential represent an authentication mechanism for a Platform
+// Credential represents an authentication mechanism for a Platform
 type Credential struct {
+	// Deprecated
+	Password string `json:"password,omitempty"`
+
 	Name           string         `json:"name"`
 	Username       string         `json:"username"`
-	Password       string         `json:"password"`
 	APIKeyPair     *APIKeyPair    `json:"api_key_pair"`
 	CredentialType CredentialType `json:"credential_type"`
 }
