@@ -5,3 +5,10 @@ type SchemaRegistryCluster struct {
 	SchemaRegistryEndpoint string      `json:"schema_registry_endpoint"`
 	SrCredentials          *APIKeyPair `json:"schema_registry_credentials"`
 }
+
+func (s *SchemaRegistryCluster) GetId() string {
+	if s == nil {
+		return ""
+	}
+	return s.Id
+}
