@@ -6,7 +6,6 @@ import (
 	b64 "encoding/base64"
 	"fmt"
 	"net/http"
-	"os"
 	"time"
 
 	"github.com/dghubble/sling"
@@ -32,6 +31,8 @@ const (
 	userPath = "users/%s"
 )
 
+const cliProdEnv = "confluent.cloud"
+
 const (
 	cliProdEnvClientId     = "61af57740127630ce47de5be"
 	cliTestEnvClientId     = "61af57740127630ce47de5bd"
@@ -57,16 +58,17 @@ type launchDarklyManager struct {
 	version               *version.Version
 }
 
-func Init(version *version.Version, isTest, isDisabledConfig bool) {
+func Init(cfg *v1.Config) {
+	platformName := cfg.Context().GetPlatform().GetName()
 	cliBasePath := fmt.Sprintf(baseURL, auth.CCloudURL, cliProdEnvClientId)
-	if isTest {
+	if cfg.IsTest {
 		cliBasePath = fmt.Sprintf(baseURL, testserver.TestCloudUrl.String(), "1234")
-	} else if os.Getenv("XX_LAUNCH_DARKLY_TEST_ENV") != "" {
+	} else if platformName != cliProdEnv {
 		cliBasePath = fmt.Sprintf(baseURL, auth.CCloudURL, cliTestEnvClientId)
 	}
 
 	ccloudClientProvider := func(client v1.LaunchDarklyClient) *sling.Sling {
-		if isTest || os.Getenv("XX_LAUNCH_DARKLY_TEST_ENV") != "" {
+		if cfg.IsTest || platformName != cliProdEnv {
 			return sling.New().Base(fmt.Sprintf(baseURL, auth.CCloudURL, ccloudCpdEnvClientId))
 		}
 
@@ -86,10 +88,10 @@ func Init(version *version.Version, isTest, isDisabledConfig bool) {
 	Manager = launchDarklyManager{
 		cliClient:             sling.New().Base(cliBasePath),
 		ccloudClient:          ccloudClientProvider,
-		hideTimeoutWarning:    isTest,
-		isDisabled:            isDisabledConfig,
+		hideTimeoutWarning:    cfg.IsTest,
+		isDisabled:            cfg.DisableFeatureFlags,
 		timeoutWarningPrinted: false,
-		version:               version,
+		version:               cfg.Version,
 	}
 }
 
@@ -100,7 +102,7 @@ func (ld *launchDarklyManager) SetCommandAndFlags(cmd *cobra.Command, args []str
 	ld.flags = flags
 }
 
-func (ld *launchDarklyManager) BoolVariation(key string, ctx *dynamicconfig.DynamicContext, client v1.LaunchDarklyClient, shouldCache bool, defaultVal bool) bool {
+func (ld *launchDarklyManager) BoolVariation(key string, ctx *dynamicconfig.DynamicContext, client v1.LaunchDarklyClient, shouldCache, defaultVal bool) bool {
 	flagValInterface := ld.generalVariation(key, ctx, client, shouldCache, defaultVal)
 	flagVal, ok := flagValInterface.(bool)
 	if !ok {
