@@ -15,6 +15,8 @@ import (
 	"github.com/confluentinc/cli/internal/pkg/output"
 )
 
+const errorDuringTableView = "Error: internal error occurred while in table view"
+
 type InteractiveOutputController struct {
 	app           *tview.Application
 	tableView     components.TableViewInterface
@@ -34,17 +36,23 @@ func NewInteractiveOutputController(tableView components.TableViewInterface, res
 
 func (t *InteractiveOutputController) VisualizeResults() {
 	t.init()
-	t.start()
+	t.startTView() // this is blocking
+	t.close()
 }
 
-func (t *InteractiveOutputController) start() {
+func (t *InteractiveOutputController) startTView() {
 	err := t.app.Run()
 	if err != nil {
-		log.CliLogger.Errorf("Error: failed to open table view, %v", err)
-		utils.OutputErr("Error: failed to open table view")
+		log.CliLogger.Errorf("%s, %v", errorDuringTableView, err)
+		utils.OutputErr(errorDuringTableView)
 	}
 }
 
+func (t *InteractiveOutputController) close() {
+	t.resultFetcher.Close()
+	output.Println("Result retrieval aborted.")
+}
+
 func (t *InteractiveOutputController) init() {
 	t.isRowViewOpen = false
 	t.resultFetcher.SetRefreshCallback(t.renderTableAsync)
@@ -108,17 +116,13 @@ func (t *InteractiveOutputController) inputHandlerTableView(event *tcell.EventKe
 			action()
 		}
 		return nil
-	case tcell.KeyEscape:
-		fallthrough
-	case tcell.KeyCtrlQ:
-		t.exitTViewMode()
+	case tcell.KeyEscape, tcell.KeyCtrlQ:
+		t.app.Stop()
 		return nil
 	case tcell.KeyEnter:
 		t.renderRowView()
 		return nil
-	case tcell.KeyUp:
-		fallthrough
-	case tcell.KeyDown:
+	case tcell.KeyUp, tcell.KeyDown:
 		return t.handleKeyUpOrDownPress(event)
 	}
 	return event
@@ -127,7 +131,7 @@ func (t *InteractiveOutputController) inputHandlerTableView(event *tcell.EventKe
 func (t *InteractiveOutputController) getActionForShortcut(shortcut string) func() {
 	switch shortcut {
 	case components.ExitTableViewShortcut:
-		return t.exitTViewMode
+		return t.app.Stop
 	case components.ToggleTableModeShortcut:
 		return t.toggleTableMode
 	case components.ToggleRefreshShortcut:
@@ -140,12 +144,6 @@ func (t *InteractiveOutputController) getActionForShortcut(shortcut string) func
 	return nil
 }
 
-func (t *InteractiveOutputController) exitTViewMode() {
-	t.resultFetcher.Close()
-	t.app.Stop()
-	output.Println("Result retrieval aborted.")
-}
-
 func (t *InteractiveOutputController) toggleTableMode() {
 	t.resultFetcher.ToggleTableMode()
 	t.updateTable()
