@@ -19,6 +19,7 @@ func (s *CLITestSuite) TestPipeline() {
 		{args: "pipeline list", fixture: "pipeline/list.golden"},
 		{args: "pipeline describe pipe-12345", fixture: "pipeline/describe-pass.golden"},
 		{args: fmt.Sprintf("pipeline save pipe-12345 --sql-file %s", testOutputFile.Name()), fixture: "pipeline/save.golden", regex: true},
+		{args: "pipeline create --name testPipeline --ksql-cluster lksqlc-12345 --use-schema-registry", fixture: "pipeline/create-with-ksql-sr-cluster.golden"},
 		{args: "pipeline create --name testPipeline --ksql-cluster lksqlc-12345", fixture: "pipeline/create.golden"},
 		{args: "pipeline create --name testPipeline --ksql-cluster lksqlc-12345 --description testDescription", fixture: "pipeline/create.golden"},
 		{args: fmt.Sprintf("pipeline create --name testPipeline --ksql-cluster lksqlc-12345 --description testDescription --sql-file %s", testPipelineSourceCode), fixture: "pipeline/create.golden"},
@@ -38,14 +39,14 @@ func (s *CLITestSuite) TestPipeline() {
 		{args: `pipeline update pipe-12345 --secret name1=value-with,and= --secret name2=value-with\"and\' --secret name3=`, fixture: "pipeline/update-with-secret-names.golden"},
 	}
 
-	for _, tt := range tests {
-		tt.login = "cloud"
-		tt.useKafka = "lkc-12345"
-		s.runIntegrationTest(tt)
+	for _, test := range tests {
+		test.login = "cloud"
+		test.useKafka = "lkc-12345"
+		s.runIntegrationTest(test)
 	}
 }
 
-func (s *CLITestSuite) TestPipelineAutocomplete() {
+func (s *CLITestSuite) TestPipeline_Autocomplete() {
 	test := CLITest{args: `__complete pipeline describe ""`, login: "cloud", useKafka: "lkc-12345", fixture: "pipeline/describe-autocomplete.golden"}
 	s.runIntegrationTest(test)
 }
